import * as events from "aws-cdk-lib/aws-events";
import * as sns from "aws-cdk-lib/aws-sns";
import * as sqs from "aws-cdk-lib/aws-sqs";
import { Construct } from "constructs";
import { SqsToLambdaStage, SqsToLambdaStageProps } from "./sqs-lambda";
/**
 * Properties for `SnsSqsToLambdaStage`.
 */
export interface SnsToLambdaStageProps extends SqsToLambdaStageProps {
    /**
     * Preexisting SNS Topic to use in stage.
     * If not provided, a new one will be created.
     */
    readonly snsTopic?: sns.ITopic;
    /**
     * Properties for the SNS Topic that will be created by this construct
     * (if `snsTopic` is not provided).
     */
    readonly snsTopicProps?: sns.TopicProps;
    /**
     * The filter policy.
     *
     * @default - all messages are delivered
     */
    readonly filterPolicy?: {
        [attribute: string]: sns.SubscriptionFilter;
    };
    /**
     * Queue to be used as dead letter queue.
     * If not passed no dead letter queue is enabled.
     *
     * @default - No dead letter queue enabled.
     */
    readonly snsDlqEnabled?: boolean;
    /**
     * The message to the queue is the same as it was sent to the topic
     *
     * If false, the message will be wrapped in an SNS envelope.
     *
     * @default false
     */
    readonly rawMessageDelivery?: boolean;
    /**
     * Whether to disable the default topic policy generated by SnsFactory.
     * @see SnsFactory.secureSnsTopicPolicy
     *
     * @default false
     */
    readonly disableDefaultTopicPolicy?: boolean;
}
/**
 * Stage implements an SNS Topic connected to an Amazon SQS queue and an AWS Lambda function,
 * with an optional DLQ.
 */
export declare class SnsSqsToLambdaStage extends SqsToLambdaStage {
    readonly targets?: events.IRuleTarget[];
    readonly eventPattern?: events.EventPattern;
    readonly topic: sns.ITopic;
    readonly snsDeadLetterQueue?: sqs.Queue;
    /**
     * Constructs `SnsSqsToLambdaStage`.
     * @param scope Scope within which this construct is defined.
     * @param id Identifier of the stage.
     * @param props Properties for the stage.
     */
    constructor(scope: Construct, id: string, props: SnsToLambdaStageProps);
}
